@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 
 use strict;
 use warnings;
@@ -165,10 +165,13 @@ sub fingering {
             my $diff = $target - _lowest_c($pitches);
             my ($str, $pos) = split /-/, $fingering;
             my $p = $pos + $diff;
-            if ($p == 0) {
+            if ($p == 0 && $str !~ /0/) {
                 $str = _decrement_fingering($str);
                 $p++;
             }
+            elsif ($p != 0 && $str =~ /0/) {
+                $str = _increment_fingering($str);
+            }
             push @fingering, $str . '-' . $p;
         }
     }
@@ -208,7 +211,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
@@ -218,13 +221,12 @@ version 0.0602
 
   my $chords = $mcg->transform('D3', 'dim7');
   my $chord = $mcg->transform('D3', 'dim7', 0);
+  # MIDI:
+  #$score->n('wn', @$chord);
 
   my $fingerings = $mcg->fingering('D3', 'dim7');
   my $fingering = $mcg->fingering('D3', 'dim7', 0);
 
-  # MIDI:
-  #$score->n('wn', @$chord);
-
   my $voicings = $mcg->voicings('dim7');
 
   $voicings = $mcg->voicings('dim7', 'ISO');
